from enum import Enum
from typing import List, Optional


class BlockTypeEnum(Enum):
    NormalText = "normal"
    BoldText = "bold"
    ItalicText = "italic"
    UnderlineText = "underline"
    LightText = "light"
    Title = "title"
    Custom = "custom"

    def __str__(self):
        return self.value


class BlockLevelEnum(Enum):
    Paragraph = "paragraph"
    Sentence = "sentence"
    Word = "word"

    def __str__(self):
        return self.value


class Block:
    def __init__(self,  level: BlockLevelEnum, type: BlockTypeEnum, content: Optional[str],  subBlocks: Optional[List['Block']]):
        self.content = content
        self.type = type
        self.level = level
        self.subBlocks = subBlocks

    def __dict__(self):
        subBlocks = []
        if self.subBlocks is not None:
            subBlocks = [subBlock.__dict__() for subBlock in self.subBlocks]

        return {
            "content": self.content,
            "type": self.type.value,
            "level": self.level.value,
            "subBlocks": subBlocks
        }
